@@ -13,7 +13,7 @@ dpkg-checkbuilddeps -d 'python3-apt, apt-btrfs-snapshot, parsewiki, python3-feed
 (cd utils && ./demotions.py yakkety zesty > demoted.cfg)
 # when this gets enabled, make sure to add symlink in DistUpgrade
 # echo "Running lts demotions"
-#(cd utils && ./demotions.py trusty xenial > demoted.cfg.trusty)
+(cd utils && ./demotions.py xenial zesty > demoted.cfg.xenial)
 
 # update apt_btrfs_snapshot.py copy, this needs an installed
 # apt-btrfs-snapshot on the build machine
